@@ -5,21 +5,30 @@ import argparse
 import numpy as np
 from sklearn.decomposition import TruncatedSVD
 
-def embed_mergechr(embed_list, outprefix, dim=50):
-	embedlist = np.loadtxt(embed_file, dtype=np.str)[:,0]
+def embed_mergechr(embed_list, outprefix, dim=20, norm_sig=True):
+	embedlist = np.loadtxt(embed_list, dtype=np.str)
 	matrix_reduce = np.concatenate([np.load(x) for x in embedlist], axis=1)
+	if norm_sig:
+		matrix_reduce = matrix_reduce[1:] / matrix_reduce[0]
+	else:
+		matrix_reduce = matrix_reduce[1:]
 	svd = TruncatedSVD(n_components=dim, algorithm='arpack')
 	matrix_reduce = svd.fit_transform(matrix_reduce)
-	matrix_reduce = matrix_reduce / svd.singular_values_
-	with h5py.File(f'{outprefix}.svd{dim}.hdf5', 'a') as f:
+	if norm_sig:
+		matrix_reduce = matrix_reduce / svd.singular_values_
+	with h5py.File(f'{outprefix}.svd{dim}.hdf5', 'w') as f:
 		tmp = f.create_dataset('data', matrix_reduce.shape, dtype='float32', compression='gzip')
 		tmp[()] = matrix_reduce
 	return
 
+'''
 parser = argparse.ArgumentParser()
 parser.add_argument('--embed_list', type=str, default=None, help='Full path of a file containing the full path to dimension reduction files of all chromosomes')
 parser.add_argument('--outprefix', type=str, default=None, help='Prefix of final dimension reduction file including directory')
-parser.add_argument('--dim', type=int, default=50, help='Number of dimensions to return from SVD')
+parser.add_argument('--dim', type=int, default=20, help='Number of dimensions to return from SVD')
+parser.add_argument('--use_pc', dest='norm_sig', action='store_false', help='Not to normalize PCs by singular values')
+parser.set_defaults(norm_sig=True)
 opt = parser.parse_args()
 
-embed_mergechr(opt.embed_list, opt.outprefix, opt.dim)
+embed_mergechr(opt.embed_list, opt.outprefix, opt.dim, opt.norm_sig)
+'''
